#ifndef LOGGRAYMAP_H
#define LOGGRAYMAP_H

#include "QColorMapAction.h"
#include <cmath>

using namespace std;

/**
 * @brief Colormap using logarithmic distributed gray values.
 */
class LogGrayMap : public QColorMapAction
{
public:
    LogGrayMap(QObject *parent) : QColorMapAction(tr("Gray (logarithmic)"),parent) {}

    void apply(vector<QRgb> &colormap)
    {
        int N=colormap.size();
        double scale=255.0/log(N+1.0);
        double val=1.0;
        double step=1.0+1.0/N;
        for(int i=0;i<N;i++)
        {
            uint color=uint(scale*log(val));
            colormap[i]=qRgb(color,color,color);
            val+=step;
        }
    }
};

#endif // LOGGRAYMAP_H
